use tokio::task::spawn_blocking;

use crate::{markups::menu_markup_sync, prelude::*};

/// Handles the messages which weren't matched by any commands or states
pub async fn default(
    bot: Throttle<Bot>,
    msg: Message,
    db: Pool,
    locale: LocaleRef,
) -> crate::Result<()> {
    let user_id = msg.get_user_id()?;

    if msg.text().is_none() || !MasterPass::exists(user_id, &db).await? {
        bot.send_message(msg.chat.id, &locale.unknown_command_use_help)
            .reply_markup(deletion_markup(locale))
            .await?;
        return Ok(());
    }

    let names = Account::search(user_id, msg.text().unwrap().to_owned(), &db).await?;
    let markup = spawn_blocking(move || menu_markup_sync("get", names)).await?;

    if markup.inline_keyboard.is_empty() {
        bot.send_message(msg.chat.id, &locale.no_accounts_found)
            .reply_markup(deletion_markup(locale))
            .await?;
        return Ok(());
    }

    bot.send_message(msg.chat.id, &locale.choose_account)
        .reply_markup(markup)
        .await?;

    Ok(())
}
